Changelog
=========

There's a frood who really knows where his towel is.

1.0.0 (2020-09-09)
------------------

- Make {{url}} available in overlay templates so you can put a link to a carousel item. [fredvd]

1.0b1 (2016-06-21)
------------------

- ICarouselTile tile now inherits from IListTile instead of IPersistentCoverTile.
  [hvelarde]

- Make package compatible with collective.cover >= 1.0b1.
  It is recommended that you upgrade to the latest version of the package.
  [rodfersou, hvelarde, fredvd]

- Register collective.js.cycle2 resources used in this package in the JavaScript registry.
  [djowett]

- Add Dutch translations.
  [fredvd]


1.0a1 (2015-05-27)
------------------

- Initial release.
